@@ -129,7 +129,7 @@ __lws_threadpool_task_dump(struct lws_threadpool_task *task, char *buf, int len)
 	int syncms = 0, runms = 0;
 
 	if (!task->acquired) {
-		buf += lws_snprintf(buf, end - buf,
+		buf += lws_snprintf(buf, lws_ptr_diff_size_t(end, buf),
 				    "task: %s, QUEUED queued: %dms",
 				    task->name, ms_delta(now, task->created));
 
@@ -143,7 +143,7 @@ __lws_threadpool_task_dump(struct lws_threadpool_task *task, char *buf, int len)
 		syncms = (int)task->acc_syncing;
 
 	if (!task->done) {
-		buf += lws_snprintf(buf, end - buf,
+		buf += lws_snprintf(buf, lws_ptr_diff_size_t(end, buf),
 			"task: %s, ONGOING state %d (%dms) alive: %dms "
 			"(queued %dms, acquired: %dms, "
 			"run: %d%%, sync: %d%%)", task->name, task->status,
@@ -157,7 +157,7 @@ __lws_threadpool_task_dump(struct lws_threadpool_task *task, char *buf, int len)
 		return;
 	}
 
-	lws_snprintf(buf, end - buf,
+	lws_snprintf(buf, lws_ptr_diff_size_t(end, buf),
 		"task: %s, DONE state %d lived: %dms "
 		"(queued %dms, on thread: %dms, "
 		"ran: %d%%, synced: %d%%)", task->name, task->status,
@@ -259,8 +259,8 @@ lws_threadpool_task_cleanup_destroy(struct lws_threadpool_task *task)
 
 	lws_dll2_remove(&task->list);
 
-	lwsl_thread("%s: tp %p: cleaned finished task for wsi %p\n",
-		    __func__, task->tp, task_to_wsi(task));
+	lwsl_thread("%s: tp %p: cleaned finished task for %s\n",
+		    __func__, task->tp, lws_wsi_tag(task_to_wsi(task)));
 
 	lws_free(task);
 }
@@ -283,8 +283,8 @@ __lws_threadpool_reap(struct lws_threadpool_task *task)
 				t->task_queue_next = NULL;
 				tp->done_queue_depth--;
 
-				lwsl_thread("%s: tp %s: reaped task wsi %p\n", __func__,
-					   tp->name, task_to_wsi(task));
+				lwsl_thread("%s: tp %s: reaped task %s\n", __func__,
+					   tp->name, lws_wsi_tag(task_to_wsi(task)));
 
 				break;
 			}
@@ -401,8 +401,8 @@ lws_threadpool_worker_sync(struct lws_pool *pool,
 	lwsl_debug("%s: %p: LWS_TP_RETURN_SYNC in\n", __func__, task);
 	pthread_mutex_lock(&pool->lock); /* ======================= pool lock */
 
-	lwsl_info("%s: %s: task %p (%s): syncing with wsi %p\n", __func__,
-		    pool->tp->name, task, task->name, task_to_wsi(task));
+	lwsl_info("%s: %s: task %p (%s): syncing with %s\n", __func__,
+		    pool->tp->name, task, task->name, lws_wsi_tag(task_to_wsi(task)));
 
 	temp = task->status;
 	state_transition(task, LWS_TP_STATUS_SYNCING);
@@ -426,13 +426,13 @@ lws_threadpool_worker_sync(struct lws_pool *pool,
 		}
 
 		/*
-		 * So tries times this is the maximum time between SYNC asking
+		 * So "tries" times this is the maximum time between SYNC asking
 		 * for a callback on writable and actually getting it we are
 		 * willing to sit still for.
 		 *
 		 * If it is exceeded, we will stop the task.
 		 */
-		abstime.tv_sec = time(NULL) + 2;
+		abstime.tv_sec = time(NULL) + 3;
 		abstime.tv_nsec = 0;
 
 		task->wanted_writeable_cb = 1;
@@ -458,12 +458,13 @@ lws_threadpool_worker_sync(struct lws_pool *pool,
 			task->late_sync_retries++;
 			if (!tries) {
 				lwsl_err("%s: %s: task %p (%s): SYNC timed out "
-					 "(associated wsi %p)\n",
+					 "(associated %s)\n",
 					 __func__, pool->tp->name, task,
-					 task->name, task_to_wsi(task));
+					 task->name, lws_wsi_tag(task_to_wsi(task)));
 
-				state_transition(task, LWS_TP_STATUS_STOPPING);
-				goto done;
+				pthread_mutex_unlock(&pool->lock); /* ----------------- - pool unlock */
+				lws_threadpool_dequeue_task(task);
+				return 1; /* destroyed task */
 			}
 
 			continue;
@@ -586,7 +587,7 @@ lws_threadpool_worker(void *d)
 			}
 
 			then = lws_now_usecs();
-			n = task->args.task(task->args.user, task->status);
+			n = (int)task->args.task(task->args.user, task->status);
 			lwsl_debug("   %d, status %d\n", n, task->status);
 			us_accrue(&task->acc_running, then);
 			if (n & LWS_TP_RETURN_FLAG_OUTLIVE)
@@ -605,7 +606,10 @@ lws_threadpool_worker(void *d)
 				}
 				/* block until writable acknowledges */
 				then = lws_now_usecs();
-				lws_threadpool_worker_sync(pool, task);
+				if (lws_threadpool_worker_sync(pool, task)) {
+					lwsl_notice("%s: Sync failed\n", __func__);
+					goto doneski;
+				}
 				us_accrue(&task->acc_syncing, then);
 				break;
 			case LWS_TP_RETURN_FINISHED:
@@ -688,12 +692,12 @@ lws_threadpool_create(struct lws_context *context,
 	va_list ap;
 	int n;
 
-	tp = lws_malloc(sizeof(*tp) + (sizeof(struct lws_pool) * args->threads),
+	tp = lws_malloc(sizeof(*tp) + (sizeof(struct lws_pool) * (unsigned int)args->threads),
 			"threadpool alloc");
 	if (!tp)
 		return NULL;
 
-	memset(tp, 0, sizeof(*tp) + (sizeof(struct lws_pool) * args->threads));
+	memset(tp, 0, sizeof(*tp) + (sizeof(struct lws_pool) * (unsigned int)args->threads));
 	tp->pool_list = (struct lws_pool *)(tp + 1);
 	tp->max_queue_depth = args->max_queue_depth;
 
@@ -872,8 +876,8 @@ lws_threadpool_dequeue_task(struct lws_threadpool_task *task)
 			tp->done_queue_depth++;
 			task->done = lws_now_usecs();
 
-			lwsl_debug("%s: tp %p: removed queued task wsi %p\n",
-				    __func__, tp, task_to_wsi(task));
+			lwsl_debug("%s: tp %p: removed queued task %s\n",
+				    __func__, tp, lws_wsi_tag(task_to_wsi(task)));
 
 			break;
 		}
@@ -924,15 +928,16 @@ lws_threadpool_dequeue_task(struct lws_threadpool_task *task)
 		pthread_mutex_unlock(&tp->pool_list[n].lock);
 
 		lwsl_debug("%s: tp %p: request stop running task "
-			    "for wsi %p\n", __func__, tp, task_to_wsi(task));
+			    "for %s\n", __func__, tp,
+			    lws_wsi_tag(task_to_wsi(task)));
 
 		break;
 	}
 
 	if (n == tp->threads_in_pool) {
 		/* can't find it */
-		lwsl_notice("%s: tp %p: no task for wsi %p, decoupling\n",
-			    __func__, tp, task_to_wsi(task));
+		lwsl_notice("%s: tp %p: no task for %s, decoupling\n",
+			    __func__, tp, lws_wsi_tag(task_to_wsi(task)));
 		lws_dll2_remove(&task->list);
 		task->args.wsi = NULL;
 #if defined(LWS_WITH_SECURE_STREAMS)
@@ -1029,9 +1034,9 @@ lws_threadpool_enqueue(struct lws_threadpool *tp,
 #endif
 		lws_dll2_add_tail(&task->list, &args->wsi->tp_task_owner);
 
-	lwsl_thread("%s: tp %s: enqueued task %p (%s) for wsi %p, depth %d\n",
-		    __func__, tp->name, task, task->name, task_to_wsi(task),
-		    tp->queue_depth);
+	lwsl_thread("%s: tp %s: enqueued task %p (%s) for %s, depth %d\n",
+		    __func__, tp->name, task, task->name,
+		    lws_wsi_tag(task_to_wsi(task)), tp->queue_depth);
 
 	/* alert any idle thread there's something new on the task list */
 
@@ -1161,6 +1166,22 @@ lws_threadpool_foreach_task_ss(struct lws_ss_handle *ss, void *user,
 }
 #endif
 
+static int
+disassociate_wsi(struct lws_threadpool_task *task,
+		  void *user)
+{
+	task->args.wsi = NULL;
+	lws_dll2_remove(&task->list);
+
+	return 0;
+}
+
+void
+lws_threadpool_wsi_closing(struct lws *wsi)
+{
+	lws_threadpool_foreach_task_wsi(wsi, NULL, disassociate_wsi);
+}
+
 struct lws_threadpool_task *
 lws_threadpool_get_task_wsi(struct lws *wsi)
 {
