@@ -564,7 +564,7 @@ lws_plat_mbedtls_net_send(void *ctx, const uint8_t *buf, size_t len)
 	if (fd < 0)
 		return MBEDTLS_ERR_NET_INVALID_CONTEXT;
 
-	ret = send(fd, buf, (unsigned int)len, 0);
+	ret = send(fd, (const char *)buf, (unsigned int)len, 0);
 	if (ret >= 0)
 		return ret;
 
@@ -589,7 +589,7 @@ lws_plat_mbedtls_net_recv(void *ctx, unsigned char *buf, size_t len)
 	if (fd < 0)
 		return MBEDTLS_ERR_NET_INVALID_CONTEXT;
 
-	ret = (int)recv(fd, buf, (unsigned int)len, 0);
+	ret = (int)recv(fd, (char *)buf, (unsigned int)len, 0);
 	if (ret >= 0)
 		return ret;
 
