@@ -38,15 +38,7 @@ lws_tls_server_client_cert_verify_config(struct lws_vhost *vh)
 		return 0;
 	}
 
-	/*
-	 * The wrapper has this messed-up mapping:
-	 *
-	 * 	   else if (ctx->verify_mode == SSL_VERIFY_FAIL_IF_NO_PEER_CERT)
-	 *     mode = MBEDTLS_SSL_VERIFY_OPTIONAL;
-	 *
-	 * ie the meaning is inverted.  So where we should test for ! we don't
-	 */
-	if (lws_check_opt(vh->options, LWS_SERVER_OPTION_PEER_CERT_NOT_REQUIRED))
+	if (!lws_check_opt(vh->options, LWS_SERVER_OPTION_PEER_CERT_NOT_REQUIRED))
 		verify_options = SSL_VERIFY_FAIL_IF_NO_PEER_CERT;
 
 	lwsl_notice("%s: vh %s requires client cert %d\n", __func__, vh->name,
@@ -125,7 +117,7 @@ lws_tls_server_certs_load(struct lws_vhost *vhost, struct lws *wsi,
 		return 0;
 	}
 
-	n = lws_tls_generic_cert_checks(vhost, cert, private_key);
+	n = (int)lws_tls_generic_cert_checks(vhost, cert, private_key);
 
 	if (n == LWS_TLS_EXTANT_NO && (!mem_cert || !mem_privkey))
 		return 0;
@@ -161,7 +153,7 @@ lws_tls_server_certs_load(struct lws_vhost *vhost, struct lws *wsi,
 		return 1;
 	}
 
-	err = SSL_CTX_use_certificate_ASN1(vhost->tls.ssl_ctx, flen, p);
+	err = SSL_CTX_use_certificate_ASN1(vhost->tls.ssl_ctx, (int)flen, p);
 	lws_free_set_NULL(p);
 	if (!err) {
 		lwsl_err("Problem loading cert\n");
@@ -176,7 +168,7 @@ lws_tls_server_certs_load(struct lws_vhost *vhost, struct lws *wsi,
 		return 1;
 	}
 
-	err = SSL_CTX_use_PrivateKey_ASN1(0, vhost->tls.ssl_ctx, p, flen);
+	err = SSL_CTX_use_PrivateKey_ASN1(0, vhost->tls.ssl_ctx, p, (long)flen);
 	lws_free_set_NULL(p);
 	if (!err) {
 		lwsl_err("Problem loading key\n");
@@ -198,7 +190,7 @@ lws_tls_server_vhost_backend_init(const struct lws_context_creation_info *info,
 	lws_filepos_t flen;
 	int n;
 
-	vhost->tls.ssl_ctx = SSL_CTX_new(method);	/* create context */
+	vhost->tls.ssl_ctx = SSL_CTX_new(method, &vhost->context->mcdc);	/* create context */
 	if (!vhost->tls.ssl_ctx) {
 		lwsl_err("problem creating ssl context\n");
 		return 1;
@@ -262,7 +254,7 @@ lws_tls_server_new_nonblocking(struct lws *wsi, lws_sockfd_type accept_fd)
 		return 1;
 	}
 
-	SSL_set_fd(wsi->tls.ssl, accept_fd);
+	SSL_set_fd(wsi->tls.ssl, (int)accept_fd);
 
 	if (wsi->a.vhost->tls.ssl_info_event_mask)
 		SSL_set_info_callback(wsi->tls.ssl, lws_ssl_info_callback);
@@ -279,7 +271,9 @@ int
 #endif
 lws_tls_server_abort_connection(struct lws *wsi)
 {
-	__lws_tls_shutdown(wsi);
+	if (wsi->tls.use_ssl)
+		__lws_tls_shutdown(wsi);
+	
 	SSL_free(wsi->tls.ssl);
 
 	return 0;
@@ -315,8 +309,8 @@ lws_tls_server_accept(struct lws *wsi)
 	}
 
 	m = SSL_get_error(wsi->tls.ssl, n);
-	lwsl_notice("%s: %p: accept SSL_get_error %d errno %d\n", __func__,
-		   wsi, m, errno);
+	lwsl_debug("%s: %s: accept SSL_get_error %d errno %d\n", __func__,
+		    lws_wsi_tag(wsi), m, errno);
 
 	// mbedtls wrapper only
 	if (m == SSL_ERROR_SYSCALL && errno == 11)
@@ -464,7 +458,7 @@ lws_tls_acme_sni_cert_create(struct lws_vhost *vhost, const char *san_a,
 			     const char *san_b)
 {
 	int buflen = 0x560;
-	uint8_t *buf = lws_malloc(buflen, "tmp cert buf"), *p = buf, *pkey_asn1;
+	uint8_t *buf = lws_malloc((unsigned int)buflen, "tmp cert buf"), *p = buf, *pkey_asn1;
 	struct lws_genrsa_ctx ctx;
 	struct lws_gencrypto_keyelem el[LWS_GENCRYPTO_RSA_KEYEL_COUNT];
 	uint8_t digest[32];
@@ -483,31 +477,31 @@ lws_tls_acme_sni_cert_create(struct lws_vhost *vhost, const char *san_a,
 	}
 
 	n = sizeof(ss_cert_leadin);
-	memcpy(p, ss_cert_leadin, n);
+	memcpy(p, ss_cert_leadin, (unsigned int)n);
 	p += n;
 
 	adj = (0x0556 - 0x401) + (keybits / 4) + 1;
-	buf[2] = adj >> 8;
-	buf[3] = adj & 0xff;
+	buf[2] = (uint8_t)(adj >> 8);
+	buf[3] = (uint8_t)(adj & 0xff);
 
 	adj = (0x033e - 0x201) + (keybits / 8) + 1;
-	buf[6] = adj >> 8;
-	buf[7] = adj & 0xff;
+	buf[6] = (uint8_t)(adj >> 8);
+	buf[7] = (uint8_t)(adj & 0xff);
 
 	adj = (0x0222 - 0x201) + (keybits / 8) + 1;
-	buf[0xc3] = adj >> 8;
-	buf[0xc4] = adj & 0xff;
+	buf[0xc3] = (uint8_t)(adj >> 8);
+	buf[0xc4] = (uint8_t)(adj & 0xff);
 
 	adj = (0x020f - 0x201) + (keybits / 8) + 1;
-	buf[0xd6] = adj >> 8;
-	buf[0xd7] = adj & 0xff;
+	buf[0xd6] = (uint8_t)(adj >> 8);
+	buf[0xd7] = (uint8_t)(adj & 0xff);
 
 	adj = (0x020a - 0x201) + (keybits / 8) + 1;
-	buf[0xdb] = adj >> 8;
-	buf[0xdc] = adj & 0xff;
+	buf[0xdb] = (uint8_t)(adj >> 8);
+	buf[0xdc] = (uint8_t)(adj & 0xff);
 
-	*p++ = ((keybits / 8) + 1) >> 8;
-	*p++ = ((keybits / 8) + 1) & 0xff;
+	*p++ = (uint8_t)(((keybits / 8) + 1) >> 8);
+	*p++ = (uint8_t)(((keybits / 8) + 1) & 0xff);
 
 	/* we need to drop 1 + (keybits / 8) bytes of n in here, 00 + key */
 
@@ -524,8 +518,8 @@ lws_tls_acme_sni_cert_create(struct lws_vhost *vhost, const char *san_a,
 	p += SAN_A_LENGTH;
 	memcpy(p, ss_cert_sig_leadin, sizeof(ss_cert_sig_leadin));
 
-	p[17] = ((keybits / 8) + 1) >> 8;
-	p[18] = ((keybits / 8) + 1) & 0xff;
+	p[17] = (uint8_t)(((keybits / 8) + 1) >> 8);
+	p[18] = (uint8_t)(((keybits / 8) + 1) & 0xff);
 
 	p += sizeof(ss_cert_sig_leadin);
 
@@ -534,7 +528,7 @@ lws_tls_acme_sni_cert_create(struct lws_vhost *vhost, const char *san_a,
 	if (lws_genhash_init(&hash_ctx, LWS_GENHASH_TYPE_SHA256))
 		goto bail2;
 
-	if (lws_genhash_update(&hash_ctx, buf, lws_ptr_diff(p, buf))) {
+	if (lws_genhash_update(&hash_ctx, buf, lws_ptr_diff_size_t(p, buf))) {
 		lws_genhash_destroy(&hash_ctx, NULL);
 
 		goto bail2;
@@ -545,16 +539,16 @@ lws_tls_acme_sni_cert_create(struct lws_vhost *vhost, const char *san_a,
 	/* sign the hash */
 
 	n = lws_genrsa_hash_sign(&ctx, digest, LWS_GENHASH_TYPE_SHA256, p,
-				 buflen - lws_ptr_diff(p, buf));
+				 (size_t)((size_t)buflen - lws_ptr_diff_size_t(p, buf)));
 	if (n < 0)
 		goto bail2;
 	p += n;
 
-	pkey_asn1 = lws_malloc(pkey_asn1_len, "mbed crt tmp");
+	pkey_asn1 = lws_malloc((unsigned int)pkey_asn1_len, "mbed crt tmp");
 	if (!pkey_asn1)
 		goto bail2;
 
-	m = lws_genrsa_render_pkey_asn1(&ctx, 1, pkey_asn1, pkey_asn1_len);
+	m = lws_genrsa_render_pkey_asn1(&ctx, 1, pkey_asn1, (size_t)pkey_asn1_len);
 	if (m < 0) {
 		lws_free(pkey_asn1);
 		goto bail2;
@@ -627,7 +621,7 @@ lws_tls_acme_sni_csr_create(struct lws_context *context, const char *elements[],
 	mbedtls_pk_context mpk;
 	int buf_size = 4096, n;
 	char subject[200], *p = subject, *end = p + sizeof(subject) - 1;
-	uint8_t *buf = malloc(buf_size); /* malloc because given to user code */
+	uint8_t *buf = malloc((unsigned int)buf_size); /* malloc because given to user code */
 
 	if (!buf)
 		return -1;
@@ -641,7 +635,7 @@ lws_tls_acme_sni_csr_create(struct lws_context *context, const char *elements[],
 	}
 
 	n = mbedtls_rsa_gen_key(mbedtls_pk_rsa(mpk), _rngf, context,
-				lws_plat_recommended_rsa_bits(), 65537);
+				(unsigned int)lws_plat_recommended_rsa_bits(), 65537);
 	if (n) {
 		lwsl_notice("%s: failed to generate keys\n", __func__);
 
@@ -654,7 +648,7 @@ lws_tls_acme_sni_csr_create(struct lws_context *context, const char *elements[],
 		if (p != subject)
 			*p++ = ',';
 		if (elements[n])
-			p += lws_snprintf(p, end - p, "%s=%s", x5[n],
+			p += lws_snprintf(p, lws_ptr_diff_size_t(end, p), "%s=%s", x5[n],
 					  elements[n]);
 	}
 
@@ -669,7 +663,7 @@ lws_tls_acme_sni_csr_create(struct lws_context *context, const char *elements[],
 	 * return value to determine where you should start
 	 * using the buffer
 	 */
-	n = mbedtls_x509write_csr_der(&csr, buf, buf_size, _rngf, context);
+	n = mbedtls_x509write_csr_der(&csr, buf, (size_t)buf_size, _rngf, context);
 	if (n < 0) {
 		lwsl_notice("%s: write csr der failed\n", __func__);
 		goto fail1;
@@ -677,7 +671,7 @@ lws_tls_acme_sni_csr_create(struct lws_context *context, const char *elements[],
 
 	/* we have it in DER, we need it in b64URL */
 
-	n = lws_jws_base64_enc((char *)(buf + buf_size) - n, n,
+	n = lws_jws_base64_enc((char *)(buf + buf_size) - n, (size_t)n,
 			       (char *)dcsr, csr_len);
 	if (n < 0)
 		goto fail1;
@@ -688,7 +682,7 @@ lws_tls_acme_sni_csr_create(struct lws_context *context, const char *elements[],
 	 * one step
 	 */
 
-	if (mbedtls_pk_write_key_pem(&mpk, buf, buf_size)) {
+	if (mbedtls_pk_write_key_pem(&mpk, buf, (size_t)buf_size)) {
 		lwsl_notice("write key pem failed\n");
 		goto fail1;
 	}
