@@ -904,37 +904,67 @@ lws_tls_client_create_vhost_context(struct lws_vhost *vh,
 			 SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER |
 			 SSL_MODE_RELEASE_BUFFERS);
 
-	if (info->ssl_client_options_set)
-		SSL_CTX_set_options(vh->tls.ssl_client_ctx,
+#if !defined(USE_WOLFSSL)
+#if defined(LWS_WITH_BORINGSSL)
+				uint32_t
+#else
+#if (OPENSSL_VERSION_NUMBER >= 0x10003000l) && \
+	!defined(LIBRESSL_VERSION_NUMBER) /* not documented by openssl */
+		unsigned long
+#else
+		long
+#endif
+#endif
+#else
+		long
+#endif
+			ssl_client_options_set_value =
 #if !defined(USE_WOLFSSL)
 #if defined(LWS_WITH_BORINGSSL)
 				(uint32_t)
 #else
 #if (OPENSSL_VERSION_NUMBER >= 0x10003000l) && \
 	!defined(LIBRESSL_VERSION_NUMBER) /* not documented by openssl */
-				    (unsigned long)
+				(unsigned long)
 #else
-				    (long)
+				(long)
 #endif
 #endif
 #endif
-				    info->ssl_client_options_set);
+			info->ssl_client_options_set;
+
+	if (info->ssl_client_options_set)
+		SSL_CTX_set_options(vh->tls.ssl_client_ctx, ssl_client_options_set_value);
+
+#if (OPENSSL_VERSION_NUMBER >= 0x009080df) && !defined(USE_WOLFSSL)
 
 	/* SSL_clear_options introduced in 0.9.8m */
-#if (OPENSSL_VERSION_NUMBER >= 0x009080df) && !defined(USE_WOLFSSL)
-	if (info->ssl_client_options_clear)
-		SSL_CTX_clear_options(vh->tls.ssl_client_ctx,
+#if defined(LWS_WITH_BORINGSSL)
+                uint32_t
+#else
+#if (OPENSSL_VERSION_NUMBER >= 0x10003000l) && \
+	!defined(LIBRESSL_VERSION_NUMBER) /* not documented by openssl */
+		unsigned long
+#else
+		long
+#endif
+#endif
+
+			ssl_client_options_clear_value =
 #if defined(LWS_WITH_BORINGSSL)
 				(uint32_t)
 #else
 #if (OPENSSL_VERSION_NUMBER >= 0x10003000l) && \
 	!defined(LIBRESSL_VERSION_NUMBER) /* not documented by openssl */
-				    (unsigned long)
+				(unsigned long)
 #else
-				    (long)
+				(long)
 #endif
 #endif
-				      info->ssl_client_options_clear);
+			info->ssl_client_options_clear;
+
+	if (info->ssl_client_options_clear)
+		SSL_CTX_clear_options(vh->tls.ssl_client_ctx, ssl_client_options_clear_value);
 #endif
 
 	if (cipher_list)
